SnapshotBase

Struct SnapshotBase 

pub struct SnapshotBase<const R: usize, ObservationType: Observation<R>, RewardType: Reward> {
    pub observation: ObservationType,
    pub reward: RewardType,
    pub status: EpisodeStatus,
}
Default snapshot implementation for standard reinforcement learning observations.

SnapshotBase stores an observation, reward, and EpisodeStatus. Construct via the named constructors running, terminated, or truncated.

Type Parameters

  • R - The observation tensor rank
  • ObservationType - The type of observation (must implement Observation<R>)
  • RewardType - The type of reward (must implement Reward)

Fields

observation: ObservationType

The observation derived from the state.

reward: RewardType

The reward received from the last action.

status: EpisodeStatus

Episode lifecycle status.

Implementations

Source

impl<const R: usize, ObservationType: Observation<R>, RewardType: Reward> SnapshotBase<R, ObservationType, RewardType>

pub fn running(observation: ObservationType, reward: RewardType) -> Self

Snapshot for a step where the episode is still running.

pub fn terminated(observation: ObservationType, reward: RewardType) -> Self

Snapshot for the step on which the MDP reached a terminal state.

pub fn truncated(observation: ObservationType, reward: RewardType) -> Self

Snapshot for the step on which an external step limit was reached.