pub struct NullRenderer;Expand description
A no-op renderer with Frame = ().
Use this as the default renderer type when rendering is not needed. The compiler eliminates all calls at zero runtime cost.